#!/usr/bin/env python
# -*- coding: utf-8 -*-

from gimpfu import *
import sys
import os
import glob
import re

def log(a):
	pdb.gimp_message(a)

def python_trappingz(source_image, layer, nudes, clothed, palette, as_png):		
	nudes = nudes.strip()
	clothed = clothed.strip()
	
	output_ext = 'png' if as_png else 'gif'
	
	layer_names = os.listdir(nudes)
	nudes_names = [os.path.splitext(x)[0] for x in os.listdir(nudes + "/Main")]		
	
	if source_image.base_type == INDEXED:
		source_image = pdb.gimp_image_duplicate(source_image)
		pdb.gimp_image_convert_rgb(source_image)
	
	for index, nude in enumerate(nudes_names):
		image = pdb.gimp_image_duplicate(source_image)
				
		for layer_name in layer_names:
			old_layer = pdb.gimp_image_get_layer_by_name(image, layer_name)
			
			layer_path_mask = os.path.join(nudes, layer_name, nude + ".*")
			found_layer_replacement = glob.glob(layer_path_mask)			
			
			if found_layer_replacement:
				layer_path = found_layer_replacement[0]
				new_layer = pdb.gimp_file_load_layer(image, layer_path)
				pdb.gimp_image_set_active_layer(image, old_layer)
				pdb.gimp_image_insert_layer(image, new_layer, None, -1)
				
			pdb.gimp_image_remove_layer(image, old_layer)
		
		merged_layers = pdb.gimp_image_merge_visible_layers(image, CLIP_TO_IMAGE)
		pdb.gimp_convert_indexed(image, FSLOWBLEED_DITHER, CUSTOM_PALETTE, 0, FALSE, FALSE, palette)

		output_file_name = nude
		
		match = re.search('(?<=\ABody_).+\Z', os.path.basename(clothed))
		if match:
			output_file_name = "body" + match.group(0) + "_" + nude + "_pir"
		
		pdb.gimp_file_save(image, merged_layers, os.path.join(clothed, output_file_name + "." + output_ext), '?')
		pdb.gimp_image_delete(image)


register(
	"python-fu-trappingz",
	"Generates paper dolls for OpenXCOM",
	"Generates paper dolls for OpenXCOM. 'Nudes' dir should contain dirs with images to replace layers of current image with same names. One of them should be named Main and have files for all needed paperdolls.",
	"Alexander Petrov",
	"Alexander Petrov (baturinsky@gmail.com)",
	"2017",
	"<Image>/Image/Trappingz Ahoy",
	"*",
	[
		(PF_DIRNAME, "nudes", "Nudes folder", "nudes", "./nudes"),
		(PF_DIRNAME, "clothed", "Clothed folder", "clothed", "./clothed"),
		(PF_PALETTE , "palette", "Battlescape palette", "XCOM-BattleScape.gpl"),		
		(PF_TOGGLE, "as_png", "Save as png (otherwise gif)", 0),
	],
	[],
	python_trappingz
) 

main()